==> dnv_bladed_models-0.4.0.tar.gz: dnv_bladed_models-0.4.0/src/dnv_bladed_models/pitch_system_rotary_drive.py <==
# coding: utf-8

from __future__ import annotations

from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra,PrivateAttr  # noqa: F401
from pydantic import ValidationError
from pydantic.error_wrappers import ErrorWrapper
from pydantic.utils import ROOT_KEY
from json import encoder

from dnv_bladed_models.actuator_response import ActuatorResponse

from dnv_bladed_models.linear_spring_damper import LinearSpringDamper

from dnv_bladed_models.pitch_actuator import PitchActuator

from dnv_bladed_models.pitch_torque_limits import PitchTorqueLimits



from .schema_helper import SchemaHelper 
from .models_impl import *
from .common_base_model import CommonBaseModel

class PitchSystemRotaryDrive(PitchActuator, ActuatorDriveType='RotaryDrive'):
    r"""
    A rotary pitch actuation system.
    
    Attributes:
    ----------
    ActuatorDriveType : str, default='RotaryDrive'
        Defines the specific type of ActuatorDrive model in use.  For a `RotaryDrive` object, this must always be set to a value of `RotaryDrive`.

    TorqueResponse : ActuatorResponse, abstract

    GearRatio : float, default=1
        The combined gearbox and pinion to ring gear ratio (gearbox ratio multiplied by pnion to ring gear ratio).

    GearEfficiency : float, default=1
        The efficiency between actuator motor and bearing.

    MotorInertia : float, default=0
        The rotational inertia of the motor, referred to the high speed side of the pitch gearbox.

    BrakeTorque : float, default=0
        The maximum restraining brake torque applied when the safety limit switches are tripped or permanently on in idling and parked simulations.

    TorqueLimits : PitchTorqueLimits

    BackupPowerTorqueLimits : PitchTorqueLimits

    TorqueLimitsOnceSafetySystemTripped : PitchTorqueLimits

    LinearSpringDamper : LinearSpringDamper

    Notes:
    -----
    TorqueResponse has the following concrete types:
        - FirstOrderActuatorResponse
        - InstantaneousActuatorResponse
        - SecondOrderActuatorResponse
    
    """
    _relative_schema_path: str = PrivateAttr('Components/PitchSystem/PitchActuator/PitchSystemRotaryDrive.json')
    
    ActuatorDriveType: Optional[str] = Field(alias="ActuatorDriveType", default='RotaryDrive')
    TorqueResponse: Optional[ActuatorResponse] = Field(alias="TorqueResponse", default=None)
    GearRatio: Optional[float] = Field(alias="GearRatio", default=1)
    GearEfficiency: Optional[float] = Field(alias="GearEfficiency", default=1)
    MotorInertia: Optional[float] = Field(alias="MotorInertia", default=0)
    BrakeTorque: Optional[float] = Field(alias="BrakeTorque", default=0)
    TorqueLimits: Optional[PitchTorqueLimits] = Field(alias="TorqueLimits", default=None)
    BackupPowerTorqueLimits: Optional[PitchTorqueLimits] = Field(alias="BackupPowerTorqueLimits", default=None)
    TorqueLimitsOnceSafetySystemTripped: Optional[PitchTorqueLimits] = Field(alias="TorqueLimitsOnceSafetySystemTripped", default=None)
    LinearSpringDamper: Optional[LinearSpringDamper] = Field(alias="LinearSpringDamper", default=None)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass



    def to_json(self, indent: Optional[int] = 2, **json_kwargs: Any) -> str:
        r"""
        Generates a JSON string representation of the model.

        Parameters
        ----------
        indent : int
            The whitespace indentation to use for formatting, as per json.dumps().

        Examples
        --------
        >>> model.to_json()
        Renders the full JSON representation of the model object.
        """

        json_kwargs['by_alias'] = True
        json_kwargs['exclude_unset'] = True
        json_kwargs['exclude_none'] = True
        if self.Schema is None:
            self.Schema = SchemaHelper.construct_schema_url(self._relative_schema_path)
        
        return super().json(indent=indent, **json_kwargs)


    @classmethod
    def from_file(cls: Type['Model'], path: Union[str, Path]) -> 'Model':
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        PitchSystemRotaryDrive
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PitchSystemRotaryDrive.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)


    @classmethod
    def from_json(cls: Type['Model'], b: StrBytes) -> 'Model':
        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        PitchSystemRotaryDrive
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PitchSystemRotaryDrive.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
        

    @classmethod
    def from_dict(cls: Type['Model'], obj: Any) -> 'Model':
        r"""
        Creates a model object from a dict.
        
        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        PitchSystemRotaryDrive
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)


    def to_file(self, path: Union[str, Path]):
        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')
        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())


PitchSystemRotaryDrive.update_forward_refs()

==> dnv_bladed_models-0.4.1.tar.gz: dnv_bladed_models-0.4.1/src/dnv_bladed_models/pitch_system_rotary_drive.py <==
# coding: utf-8

from __future__ import annotations

from datetime import date, datetime  # noqa: F401
from enum import Enum, IntEnum

import re  # noqa: F401
from typing import Any, Dict, List, Optional, Type, Union, Callable  # noqa: F401
from pathlib import Path
from typing import TypeVar
Model = TypeVar('Model', bound='BaseModel')
StrBytes = Union[str, bytes]

from pydantic import AnyUrl, BaseModel, EmailStr, Field, validator, root_validator, Extra,PrivateAttr  # noqa: F401
from pydantic import ValidationError
from pydantic.error_wrappers import ErrorWrapper
from pydantic.utils import ROOT_KEY
from json import encoder

from dnv_bladed_models.actuator_response import ActuatorResponse

from dnv_bladed_models.linear_spring_damper import LinearSpringDamper

from dnv_bladed_models.pitch_actuator import PitchActuator

from dnv_bladed_models.pitch_torque_limits import PitchTorqueLimits



from .schema_helper import SchemaHelper 
from .models_impl import *
from .common_base_model import CommonBaseModel

class PitchSystemRotaryDrive(PitchActuator, ActuatorDriveType='RotaryDrive'):
    r"""
    A rotary pitch actuation system.
    
    Attributes:
    ----------
    ActuatorDriveType : str, default='RotaryDrive'
        Defines the specific type of ActuatorDrive model in use.  For a `RotaryDrive` object, this must always be set to a value of `RotaryDrive`.

    TorqueResponse : ActuatorResponse, abstract

    GearRatio : float, default=1
        The combined gearbox and pinion to ring gear ratio (gearbox ratio multiplied by pnion to ring gear ratio).

    GearEfficiency : float, default=1
        The efficiency between actuator motor and bearing.

    MotorInertia : float, default=0
        The rotational inertia of the motor, referred to the high speed side of the pitch gearbox.

    BrakeTorque : float, default=0
        The maximum restraining brake torque applied when the safety limit switches are tripped or permanently on in idling and parked simulations.

    TorqueLimits : PitchTorqueLimits

    BackupPowerTorqueLimits : PitchTorqueLimits

    TorqueLimitsOnceSafetySystemTripped : PitchTorqueLimits

    LinearSpringDamper : LinearSpringDamper

    Notes:
    -----
    TorqueResponse has the following concrete types:
        - FirstOrderActuatorResponse
        - InstantaneousActuatorResponse
        - SecondOrderActuatorResponse
    
    """
    _relative_schema_path: str = PrivateAttr('Components/PitchSystem/PitchActuator/PitchSystemRotaryDrive.json')
    
    ActuatorDriveType: Optional[str] = Field(alias="ActuatorDriveType", default='RotaryDrive')
    TorqueResponse: Optional[ActuatorResponse] = Field(alias="TorqueResponse", default=None)
    GearRatio: Optional[float] = Field(alias="GearRatio", default=1)
    GearEfficiency: Optional[float] = Field(alias="GearEfficiency", default=1)
    MotorInertia: Optional[float] = Field(alias="MotorInertia", default=0)
    BrakeTorque: Optional[float] = Field(alias="BrakeTorque", default=0)
    TorqueLimits: Optional[PitchTorqueLimits] = Field(alias="TorqueLimits", default=None)
    BackupPowerTorqueLimits: Optional[PitchTorqueLimits] = Field(alias="BackupPowerTorqueLimits", default=None)
    TorqueLimitsOnceSafetySystemTripped: Optional[PitchTorqueLimits] = Field(alias="TorqueLimitsOnceSafetySystemTripped", default=None)
    LinearSpringDamper: Optional[LinearSpringDamper] = Field(alias="LinearSpringDamper", default=None)

    class Config:
        extra = Extra.forbid
        validate_assignment = True
        allow_population_by_field_name = True
        pass



    def to_json(self, indent: Optional[int] = 2, **json_kwargs: Any) -> str:
        r"""
        Generates a JSON string representation of the model.

        Parameters
        ----------
        indent : int
            The whitespace indentation to use for formatting, as per json.dumps().

        Examples
        --------
        >>> model.to_json()
        Renders the full JSON representation of the model object.
        """

        json_kwargs['by_alias'] = True
        json_kwargs['exclude_unset'] = False
        json_kwargs['exclude_none'] = True
        if self.Schema is None:
            self.Schema = SchemaHelper.construct_schema_url(self._relative_schema_path)
        
        return super().json(indent=indent, **json_kwargs)


    @classmethod
    def from_file(cls: Type['Model'], path: Union[str, Path]) -> 'Model':
        r"""
        Loads a model from a given file path.

        Parameters
        ----------
        path : string
            The file path to the model.

        Returns
        -------
        PitchSystemRotaryDrive
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PitchSystemRotaryDrive.from_file('/path/to/file')
        """
        
        return super().parse_file(path=path)


    @classmethod
    def from_json(cls: Type['Model'], b: StrBytes) -> 'Model':
        r"""
        Creates a model object from a JSON string.

        Parameters
        ----------
        b: StrBytes
            The JSON string describing the model.

        Returns
        -------
        PitchSystemRotaryDrive
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.

        Examples
        --------
        >>> model = PitchSystemRotaryDrive.from_json('{ ... }')
        """

        return super().parse_raw(
            b=b,
            content_type='application/json')
        

    @classmethod
    def from_dict(cls: Type['Model'], obj: Any) -> 'Model':
        r"""
        Creates a model object from a dict.
        
        Parameters
        ----------
        obj : Any
            The dictionary object describing the model.

        Returns
        -------
        PitchSystemRotaryDrive
            The model object.

        Raises
        ------
        ValueError, ValidationError
            If the JSON document does not correctly describe the model according to the model schema.
        """
        
        return super().parse_obj(obj=obj)


    def to_file(self, path: Union[str, Path]):
        r"""
        Writes the model as a JSON document to a file with UTF8 encoding.

        Parameters
        ----------                
        path : string
            The file path to which the model will be written.

        Examples
        --------
        >>> model.to_file('/path/to/file')
        """

        with open(file=path, mode='w', encoding="utf8") as output_file:
            output_file.write(self.to_json())


PitchSystemRotaryDrive.update_forward_refs()
